@@ -33,10 +33,14 @@ from .classes import (
     SupportsBool,
     SupportsDiv,
     SupportsGetitem,
+    SupportsGetitem2,
     SupportsGetitemIterLen,
+    SupportsGetitemIterLen2,
     SupportsGetitemLen,
+    SupportsGetitemLen2,
     SupportsIterLen,
     SupportsLen,
+    SupportsMatmul,
     SupportsMul,
     SupportsOr,
     T_BuiltinNumber,
